==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaBindingSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.knative.internal.pkg.tracker.Reference;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluent;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaBindingSpecFluent<A extends KafkaBindingSpecFluent<A>> extends Fluent<A> {


    public A addToBootstrapServers(int index,String item);
    public A setToBootstrapServers(int index,String item);
    public A addToBootstrapServers(String... items);
    public A addAllToBootstrapServers(Collection<String> items);
    public A removeFromBootstrapServers(String... items);
    public A removeAllFromBootstrapServers(Collection<String> items);
    public List<String> getBootstrapServers();
    public String getBootstrapServer(int index);
    public String getFirstBootstrapServer();
    public String getLastBootstrapServer();
    public String getMatchingBootstrapServer(Predicate<String> predicate);
    public Boolean hasMatchingBootstrapServer(Predicate<String> predicate);
    public A withBootstrapServers(List<String> bootstrapServers);
    public A withBootstrapServers(String... bootstrapServers);
    public Boolean hasBootstrapServers();
    public A addNewBootstrapServer(String arg1);
    public A addNewBootstrapServer(StringBuilder arg1);
    public A addNewBootstrapServer(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNet instead.
 * @return The buildable object.
 */
@Deprecated public KafkaNetSpec getNet();
    public KafkaNetSpec buildNet();
    public A withNet(KafkaNetSpec net);
    public Boolean hasNet();
    public KafkaBindingSpecFluent.NetNested<A> withNewNet();
    public KafkaBindingSpecFluent.NetNested<A> withNewNetLike(KafkaNetSpec item);
    public KafkaBindingSpecFluent.NetNested<A> editNet();
    public KafkaBindingSpecFluent.NetNested<A> editOrNewNet();
    public KafkaBindingSpecFluent.NetNested<A> editOrNewNetLike(KafkaNetSpec item);
    
/**
 * This method has been deprecated, please use method buildSubject instead.
 * @return The buildable object.
 */
@Deprecated public Reference getSubject();
    public Reference buildSubject();
    public A withSubject(Reference subject);
    public Boolean hasSubject();
    public KafkaBindingSpecFluent.SubjectNested<A> withNewSubject();
    public KafkaBindingSpecFluent.SubjectNested<A> withNewSubjectLike(Reference item);
    public KafkaBindingSpecFluent.SubjectNested<A> editSubject();
    public KafkaBindingSpecFluent.SubjectNested<A> editOrNewSubject();
    public KafkaBindingSpecFluent.SubjectNested<A> editOrNewSubjectLike(Reference item);
    public interface NetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaNetSpecFluent<KafkaBindingSpecFluent.NetNested<N>> {

            public N and();
            public N endNet();    }


    public interface SubjectNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReferenceFluent<KafkaBindingSpecFluent.SubjectNested<N>> {

            public N and();
            public N endSubject();    }


}

==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaBindingSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.knative.internal.pkg.tracker.Reference;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluent;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaBindingSpecFluent<A extends KafkaBindingSpecFluent<A>> extends Fluent<A> {


    public A addToBootstrapServers(int index,String item);
    public A setToBootstrapServers(int index,String item);
    public A addToBootstrapServers(String... items);
    public A addAllToBootstrapServers(Collection<String> items);
    public A removeFromBootstrapServers(String... items);
    public A removeAllFromBootstrapServers(Collection<String> items);
    public List<String> getBootstrapServers();
    public String getBootstrapServer(int index);
    public String getFirstBootstrapServer();
    public String getLastBootstrapServer();
    public String getMatchingBootstrapServer(Predicate<String> predicate);
    public Boolean hasMatchingBootstrapServer(Predicate<String> predicate);
    public A withBootstrapServers(List<String> bootstrapServers);
    public A withBootstrapServers(String... bootstrapServers);
    public Boolean hasBootstrapServers();
    public A addNewBootstrapServer(StringBuilder arg1);
    public A addNewBootstrapServer(int[] arg1,int arg2,int arg3);
    public A addNewBootstrapServer(char[] arg1);
    public A addNewBootstrapServer(StringBuffer arg1);
    public A addNewBootstrapServer(byte[] arg1,int arg2);
    public A addNewBootstrapServer(byte[] arg1);
    public A addNewBootstrapServer(char[] arg1,int arg2,int arg3);
    public A addNewBootstrapServer(byte[] arg1,int arg2,int arg3);
    public A addNewBootstrapServer(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewBootstrapServer(String arg1);
    
/**
 * This method has been deprecated, please use method buildNet instead.
 * @return The buildable object.
 */
@Deprecated public KafkaNetSpec getNet();
    public KafkaNetSpec buildNet();
    public A withNet(KafkaNetSpec net);
    public Boolean hasNet();
    public KafkaBindingSpecFluent.NetNested<A> withNewNet();
    public KafkaBindingSpecFluent.NetNested<A> withNewNetLike(KafkaNetSpec item);
    public KafkaBindingSpecFluent.NetNested<A> editNet();
    public KafkaBindingSpecFluent.NetNested<A> editOrNewNet();
    public KafkaBindingSpecFluent.NetNested<A> editOrNewNetLike(KafkaNetSpec item);
    
/**
 * This method has been deprecated, please use method buildSubject instead.
 * @return The buildable object.
 */
@Deprecated public Reference getSubject();
    public Reference buildSubject();
    public A withSubject(Reference subject);
    public Boolean hasSubject();
    public KafkaBindingSpecFluent.SubjectNested<A> withNewSubject();
    public KafkaBindingSpecFluent.SubjectNested<A> withNewSubjectLike(Reference item);
    public KafkaBindingSpecFluent.SubjectNested<A> editSubject();
    public KafkaBindingSpecFluent.SubjectNested<A> editOrNewSubject();
    public KafkaBindingSpecFluent.SubjectNested<A> editOrNewSubjectLike(Reference item);
    public interface NetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaNetSpecFluent<KafkaBindingSpecFluent.NetNested<N>> {

            public N and();
            public N endNet();    }


    public interface SubjectNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReferenceFluent<KafkaBindingSpecFluent.SubjectNested<N>> {

            public N and();
            public N endSubject();    }


}
